Simplifying math functions are simple wrappers of math function (- +).
If any of the left-hand side or right-hand side is NA, Inf or NaN it
returns any rational value, if there is any.
However, if the both values are irriational it returns NA.
The result is then passed to the
corresponding math function.
# NOT RUN {# The simplest case3 %minus_% 2# But with NA it returns 3 as if the NA were zero3 %minus_% NA# It doesnt matter if the irrational number is on left- or right-hand.NA %plus_% 5# }